==> ivcap_client-0.44.0-py3-none-any.whl: ivcap_client/api/order/order_create.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.bad_request_t import BadRequestT
from ...models.invalid_parameter_t import InvalidParameterT
from ...models.invalid_scopes_t import InvalidScopesT
from ...models.order_request_t import OrderRequestT
from ...models.order_status_rt import OrderStatusRT
from ...models.resource_not_found_t import ResourceNotFoundT
from ...types import Response


def _get_kwargs(
    *,
    json_body: OrderRequestT,
) -> Dict[str, Any]:
    pass

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/1/orders",
        "json": json_json_body,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = OrderStatusRT.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = BadRequestT.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = InvalidScopesT.from_dict(response.json())

        return response_403
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = ResourceNotFoundT.from_dict(response.json())

        return response_404
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = InvalidParameterT.from_dict(response.json())

        return response_422
    if response.status_code == HTTPStatus.NOT_IMPLEMENTED:
        response_501 = BadRequestT.from_dict(response.json())

        return response_501
    if response.status_code == HTTPStatus.SERVICE_UNAVAILABLE:
        response_503 = cast(Any, None)
        return response_503
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: OrderRequestT,
) -> Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        json_body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters':
            [{'name': 'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}],
            'policy': 'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: OrderRequestT,
) -> Optional[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        json_body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters':
            [{'name': 'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}],
            'policy': 'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: OrderRequestT,
) -> Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        json_body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters':
            [{'name': 'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}],
            'policy': 'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: OrderRequestT,
) -> Optional[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        json_body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters':
            [{'name': 'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}],
            'policy': 'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> ivcap_client-0.44.3-py3-none-any.whl: ivcap_client/api/order/order_create.py <==
from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.bad_request_t import BadRequestT
from ...models.invalid_parameter_t import InvalidParameterT
from ...models.invalid_scopes_t import InvalidScopesT
from ...models.order_request_t import OrderRequestT
from ...models.order_status_rt import OrderStatusRT
from ...models.resource_not_found_t import ResourceNotFoundT
from ...types import Response


def _get_kwargs(
    *,
    body: OrderRequestT,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/1/orders",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    if response.status_code == 200:
        response_200 = OrderStatusRT.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = BadRequestT.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == 403:
        response_403 = InvalidScopesT.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = ResourceNotFoundT.from_dict(response.json())

        return response_404
    if response.status_code == 422:
        response_422 = InvalidParameterT.from_dict(response.json())

        return response_422
    if response.status_code == 501:
        response_501 = BadRequestT.from_dict(response.json())

        return response_501
    if response.status_code == 503:
        response_503 = cast(Any, None)
        return response_503
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    body: OrderRequestT,
) -> Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters': [{'name':
            'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}], 'policy':
            'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    body: OrderRequestT,
) -> Optional[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters': [{'name':
            'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}], 'policy':
            'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    body: OrderRequestT,
) -> Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters': [{'name':
            'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}], 'policy':
            'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    body: OrderRequestT,
) -> Optional[Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]]:
    """create order

     Create a new orders and return its status.

    Args:
        body (OrderRequestT):  Example: {'name': 'Fire risk for Lot2', 'parameters': [{'name':
            'region', 'value': 'Upper Valley'}, {'name': 'threshold', 'value': '10'}], 'policy':
            'urn:ivcap:policy:123e4567-e89b-12d3-a456-426614174000', 'service':
            'urn:ivcap:service:123e4567-e89b-12d3-a456-426614174000', 'tags': ['tag1', 'tag2']}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BadRequestT, InvalidParameterT, InvalidScopesT, OrderStatusRT, ResourceNotFoundT]
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed
